parse_gram_with_header

Function parse_gram_with_header 

pub fn parse_gram_with_header(
    input: &str,
) -> Result<(Option<Record>, Vec<Pattern<Subject>>), ParseError>
Parse gram notation, separating an optional header record from the patterns.

If the first element is a bare record (identity and labels are empty, and it has no elements), it is returned separately as the header.

Arguments

  • input - Gram notation text to parse

Returns

  • Ok((Option<Record>, Vec<Pattern<Subject>>)) - Successfully parsed header and patterns
  • Err(ParseError) - If parsing fails