Function gram_validate_to_json
Source pub fn gram_validate_to_json(input: &str) -> String
Validate gram notation and return an empty string on success, or an error message.
Arguments
input - Gram notation text
Returns
A JSON string with an array of error strings (empty array = valid).